@@ -38,6 +38,7 @@ Simple example:
 """
 
 import datetime
+import decimal
 import gettext
 import locale
 import re
@@ -48,18 +49,6 @@ from kiwi import ValueUnset
 from kiwi.enums import Alignment
 from kiwi.python import enum
 
-try:
-    from decimal import Decimal, InvalidOperation
-    HAVE_DECIMAL = True
-    Decimal, InvalidOperation # pyflakes
-except:
-    HAVE_DECIMAL = False
-
-    class Decimal(float):
-        pass
-
-    InvalidOperation = ValueError
-
 if sys.platform == 'win32':
     try:
         import ctypes
@@ -78,7 +67,7 @@ __all__ = ['ValidationError', 'lformat', 'converter']
 
 _ = lambda m: gettext.dgettext('kiwi', m)
 
-number = (int, float, long, Decimal)
+number = (int, float, long, decimal.Decimal)
 
 
 class ValidationError(Exception):
@@ -366,7 +355,7 @@ class _FloatConverter(BaseConverter):
             # will also be formated as an integer, so we add a '.0'
 
             conv = get_localeconv()
-            as_str +=  conv.get('decimal_point') + '0'
+            as_str += conv.get('decimal_point') + '0'
 
         return as_str
 
@@ -389,7 +378,7 @@ converter.add(_FloatConverter)
 
 
 class _DecimalConverter(_FloatConverter):
-    type = Decimal
+    type = decimal.Decimal
     name = _('Decimal')
     align = Alignment.RIGHT
 
@@ -401,8 +390,8 @@ class _DecimalConverter(_FloatConverter):
             value = filter_locale(value)
 
         try:
-            retval = Decimal(value)
-        except InvalidOperation:
+            retval = decimal.Decimal(value)
+        except decimal.InvalidOperation:
             raise ValidationError(_("This field requires a number, not %r") %
                                   value)
 
@@ -423,7 +412,7 @@ DATE_REPLACEMENTS_WIN32 = [
     (re.compile('MM?'), '%m'),
     (re.compile('yyyyy?'), '%Y'),
     (re.compile('yy?'), '%y')
-    ]
+]
 
 # This "table" contains, associated with each
 # key (ie. strftime "conversion specifications")
@@ -442,7 +431,7 @@ DATE_MASK_TABLE = {
     '%T': ('00:00:00', _('hh:mm:ss')),
     # FIXME: locale specific
     '%r': ('00:00:00 LL', _('hh:mm:ss LL')),
-    }
+}
 
 
 class _BaseDateTimeConverter(BaseConverter):
@@ -456,6 +445,7 @@ class _BaseDateTimeConverter(BaseConverter):
 
     def __init__(self):
         self._keep_am_pm = False
+        # FIXME: There should be a way of changing this outside
         self._keep_seconds = False
 
     def get_lang_constant_win32(self):
