@@ -46,9 +46,9 @@ EnvironmentError = EnvironmentError
 # From http://tinyurl.com/77ukj
 def _is_frozen():
     "Helper function to check if we're frozen in a py2exe'd file"
-    return (hasattr(sys, "frozen") or # new py2exe
-            hasattr(sys, "importers") # old py2exe
-            or imp.is_frozen("__main__")) # tools/freeze
+    return (hasattr(sys, "frozen") or  # new py2exe
+            hasattr(sys, "importers")  # old py2exe
+            or imp.is_frozen("__main__"))  # tools/freeze
 
 
 class Environment:
@@ -113,7 +113,7 @@ class Environment:
             if resource == 'locale':
                 try:
                     self.add_resource(resource, path)
-	        except EnvironmentError:
+                except EnvironmentError:
                     continue
 
             self.add_resource(resource, path)
@@ -246,7 +246,7 @@ class Library(Environment):
             root = os.path.dirname(executable)
         # normal
         else:
-            if dirname == None:
+            if dirname is None:
                 # Figure out the absolute path to the caller
                 caller = sys._getframe(1).f_locals['__file__']
                 dirname = os.path.split(caller)[0]
