@@ -254,17 +254,18 @@ def yesno(text, parent=None, default=gtk.RESPONSE_YES,
 
 
 @contextlib.contextmanager
-def selectfile(title='', parent=None, folder=None, filters=[]):
+def selectfile(title='', parent=None, folder=None, filters=None):
     """Creates and returns a gtk.FileChooserDialog.
 
     To run the dialog, the user apps should do:
 
+        >>> import gtk
         >>> from kiwi.ui.dialogs import selectfile
         >>> with selectfile(...) as sf:
-        >>>     sf.run()
-        >>>     filename = sf.get_filename()
-        >>>     if not filename:
+        >>>     response = sf.run()
+        >>>     if response != gtk.RESPONSE_OK:
         >>>         return
+        >>>     filename = sf.get_filename()
 
     :param title: the title of the folder, defaults to 'Select file'
     :param parent: parent gtk.Window (defaults to ``None``)
@@ -278,6 +279,8 @@ def selectfile(title='', parent=None, folder=None, filters=[]):
                                         (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                          gtk.STOCK_OPEN, gtk.RESPONSE_OK))
 
+    if filters is None:
+        filters = []
     for f in filters:
         filechooser.add_filter(f)
 
@@ -324,17 +327,18 @@ def open(title='', parent=None, patterns=None, folder=None, filters=None,
                 patterns = [patterns]
             for pattern in patterns:
                 file_filter.add_pattern(pattern)
+            filters = [file_filter]
 
     with selectfile(title='', parent=parent, folder=folder,
-                    filters=[file_filter]) as sf:
+                    filters=filters) as sf:
 
-        sf.run()
-        path = sf.get_filename()
-        if not path:
+        response = sf.run()
+        if response != gtk.RESPONSE_OK:
             if with_file_chooser:
                 return None, sf
             return
 
+        path = sf.get_filename()
         if os.access(path, os.R_OK):
             if with_file_chooser:
                 return path, sf
