@@ -286,15 +286,17 @@ class Column(gobject.GObject):
     def _get_data_type(self):
         return self._data_type
 
+    def _str_compare(self, a, b):
+        return locale.strcoll(a or '', b or '')
+
     def _set_data_type(self, data):
         if data is not None:
             conv = converter.get_converter(data)
             if data == str:
-                def str_compare(a, b):
-                    return locale.strcoll(a or '', b or '')
-                self.compare = str_compare
+                compare_func = self._str_compare
             else:
-                self.compare = self.compare or conv.get_compare_function()
+                compare_func = conv.get_compare_function()
+            self.compare = self.compare or compare_func
             self.from_string = conv.from_string
         self._data_type = data
     data_type = gobject.property(getter=_get_data_type,
@@ -736,9 +738,13 @@ class SearchColumn(Column):
 
     #: overrides the function that generates the query to process the search
     search_func = gobject.property(type=object, default=None)
+
     #: names the search interface differently from the column
     search_label = gobject.property(type=object, default=None)
 
+    #: use the query on the *having* part instead of the *where*'s on
+    use_having = gobject.property(type=bool, default=False)
+
     def __init__(self, attribute, title=None, data_type=None,
                  long_title=None, valid_values=None, search_attribute=None,
                  **kwargs):
