@@ -103,7 +103,7 @@ class Yesterday(DateSearchOption):
 
 
 class LastWeek(DateSearchOption):
-    name = _('Last week')
+    name = _('Last 7 days')
 
     def get_interval(self):
         today = self.get_today_date()
@@ -111,7 +111,7 @@ class LastWeek(DateSearchOption):
 
 
 class LastMonth(DateSearchOption):
-    name = _('Last month')
+    name = _('Last 30 days')
 
     def get_interval(self):
         today = self.get_today_date()
@@ -1187,7 +1187,7 @@ class SearchContainer(gtk.VBox):
     #
 
     def add_filter(self, search_filter, position=SearchFilterPosition.BOTTOM,
-                   columns=None, callback=None):
+                   columns=None, callback=None, use_having=False):
         """
         Adds a search filter
         :param search_filter: the search filter
@@ -1204,9 +1204,11 @@ class SearchContainer(gtk.VBox):
             if callback:
                 if not callable(callback):
                     raise TypeError("callback must be callable")
-                executer.add_filter_query_callback(search_filter, callback)
+                executer.add_filter_query_callback(search_filter, callback,
+                                                   use_having=use_having)
             elif columns:
-                executer.set_filter_columns(search_filter, columns)
+                executer.set_filter_columns(search_filter, columns,
+                                            use_having=use_having)
         else:
             if columns or callback:
                 raise TypeError(
@@ -1265,7 +1267,8 @@ class SearchContainer(gtk.VBox):
         filter.set_removable()
         attr = column.search_attribute or column.attribute
         self.add_filter(filter, columns=[attr],
-                        callback=column.search_func)
+                        callback=column.search_func,
+                        use_having=column.use_having)
 
         if column.data_type is not bool:
             label = filter.get_title_label()
@@ -1455,6 +1458,8 @@ class SearchContainer(gtk.VBox):
             state = search_filter.get_state()
             if isinstance(state, DateQueryState):
                 data['start'] = state.date
+            elif isinstance(state, BoolQueryState):
+                data['value'] = state.value
             elif isinstance(state, DateIntervalQueryState):
                 data['start'] = state.start
                 data['end'] = state.end
@@ -1580,11 +1585,12 @@ class SearchSlaveDelegate(SlaveDelegate):
     #
 
     def add_filter(self, search_filter, position=SearchFilterPosition.BOTTOM,
-                   columns=None, callback=None):
+                   columns=None, callback=None, use_having=False):
         """
         See :class:`SearchSlaveDelegate.add_filter`
         """
-        self.search.add_filter(search_filter, position, columns, callback)
+        self.search.add_filter(search_filter, position, columns=columns,
+                               callback=callback, use_having=use_having)
 
     def set_query_executer(self, querty_executer):
         """
