@@ -1,16 +1,18 @@
 import cPickle
 import datetime
+import decimal
 import locale
 import unittest
 
-from kiwi.datatypes import converter, ValidationError, ValueUnset, \
-     Decimal, BaseConverter
+import mock
+from kiwi.datatypes import (converter, ValidationError, ValueUnset,
+                            BaseConverter)
 from kiwi.currency import currency
 from kiwi.python import enum
 
 # pixbuf converter
 from kiwi.ui import proxywidget
-proxywidget # pyflakes
+proxywidget  # pyflakes
 
 fake = type('fake', (object,), {})
 
@@ -20,8 +22,11 @@ def set_locale(category, name):
     try:
         locale.setlocale(category, name)
     except locale.Error:
-        print 'skipping %s, locale not available' % name
-        return False
+        try:
+            locale.setlocale(category, name + '.UTF-8')
+        except locale.Error:
+            print 'skipping %s, locale not available' % name
+            return False
     return True
 
 
@@ -44,7 +49,7 @@ class RegistryTest(unittest.TestCase):
         self.assertRaises(KeyError, converter.remove, FakeConverter)
 
     def testGetConverters(self):
-        converters = converter.get_converters((Decimal,))
+        converters = converter.get_converters((decimal.Decimal,))
         # Curreny is a subclass of Decimal, so it should be in converters
         conv = converter.get_converter(currency)
         self.assertTrue(conv in converters)
@@ -72,6 +77,71 @@ class BoolTest(unittest.TestCase):
         # you are not supposed to pass something that is not a string
         self.assertRaises(AttributeError, self.conv.from_string, None)
 
+    def testAsString(self):
+        self.assertEqual(self.conv.as_string(True), 'True')
+        self.assertEqual(self.conv.as_string(False), 'False')
+
+
+class TimeTest(unittest.TestCase):
+    def setUp(self):
+        set_locale(locale.LC_TIME, 'C')
+        self.time = datetime.time(12, 15, 30)
+        self.conv = converter.get_converter(datetime.time)
+
+    def tearDown(self):
+        set_locale(locale.LC_TIME, 'C')
+
+    def testFromStringBR(self):
+        if not set_locale(locale.LC_TIME, 'pt_BR'):
+            return
+
+        # FIXME: Those should be supported
+        #self.assertEqual(self.conv.from_string("12:15"), self.time)
+        #self.assertEqual(self.conv.from_string("12:15"), datetime.time(12, 15, 00))
+        self.assertRaises(ValidationError, self.conv.from_string, "12:15:30")
+        with mock.patch.object(self.conv, '_keep_seconds', True):
+            self.assertEqual(self.conv.from_string("12:15:30"), self.time)
+            self.assertRaises(ValidationError, self.conv.from_string, "12:15")
+
+        # test some invalid dates
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "12:70")
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "25:10")
+
+    def testFromStringUS(self):
+        if not set_locale(locale.LC_TIME, 'en_US'):
+            return
+
+        # FIXME: This should be supported
+        #self.assertEqual(self.conv.from_string("12:15"), self.time)
+        self.assertRaises(ValidationError, self.conv.from_string, "12:15:30")
+        with mock.patch.object(self.conv, '_keep_seconds', True):
+            self.assertEqual(self.conv.from_string("12:15:30"), self.time)
+            self.assertRaises(ValidationError, self.conv.from_string, "12:15")
+
+        # test some invalid dates
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "12:70")
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "25:10")
+
+    def testAsStringBR(self):
+        if not set_locale(locale.LC_TIME, 'pt_BR'):
+            return
+
+        self.assertEqual(self.conv.as_string(self.time), "12:15")
+        with mock.patch.object(self.conv, '_keep_seconds', True):
+            self.assertEqual(self.conv.as_string(self.time), "12:15:30")
+
+    def testAsStringUS(self):
+        if not set_locale(locale.LC_TIME, 'en_US'):
+            return
+
+        self.assertEqual(self.conv.as_string(self.time), "12:15")
+        with mock.patch.object(self.conv, '_keep_seconds', True):
+            self.assertEqual(self.conv.as_string(self.time), "12:15:30")
+
 
 class DateTest(unittest.TestCase):
     def setUp(self):
@@ -116,6 +186,31 @@ class DateTest(unittest.TestCase):
 
         self.assertEqual(self.conv.as_string(self.date), "12-02-1979")
 
+    def testFromStringUS(self):
+        if not set_locale(locale.LC_TIME, 'en_US'):
+            return
+
+        self.assertEqual(self.conv.from_string("2/12/1979"), self.date)
+        self.assertEqual(
+            self.conv.from_string("02/1/1979"), datetime.date(1979, 2, 1))
+        self.assertEqual(self.conv.from_string("02/12/1979"), self.date)
+
+        # test some invalid dates
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "40-10-2005")
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "30-02-2005")
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "01-01-1899")
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, "13/12/1979")
+
+    def testAsStringUS(self):
+        if not set_locale(locale.LC_TIME, 'en_US'):
+            return
+
+        self.assertEqual(self.conv.as_string(self.date), "02/12/1979")
+
     def testFromStringPortugueseBrazil(self):
         if not set_locale(locale.LC_TIME, 'Portuguese_Brazil.1252'):
             return
@@ -157,6 +252,7 @@ class CurrencyTest(unittest.TestCase):
         self.assertEqual(currency('1.994').format(), '$1.99')
         self.assertEqual(currency('1.995').format(), '$1.99')
         self.assertEqual(currency('1.996').format(), '$1.99')
+        self.assertEqual(currency(u'1.996').format(), u'$1.99')
 
     def testFormatBR(self):
         if not set_locale(locale.LC_ALL, 'pt_BR'):
@@ -170,10 +266,10 @@ class CurrencyTest(unittest.TestCase):
             c = currency('R$1.234.567,40')
         except:
             raise AssertionError("monetary separator could not be removed")
-        self.assertEqual(c, Decimal('1234567.40'))
+        self.assertEqual(c, decimal.Decimal('1234567.40'))
 
-        self.assertEqual(currency('1,234'), Decimal('1.234'))
-        self.assertEqual(currency('1.234'), Decimal('1234'))
+        self.assertEqual(currency('1,234'), decimal.Decimal('1.234'))
+        self.assertEqual(currency('1.234'), decimal.Decimal('1234'))
 
         # Sometimes it works, sometimes it doesn''10,000,000.0't
         #self.assertEqual(self.conv.from_string('0,5'), currency('0.5'))
@@ -334,52 +430,90 @@ class FloatTest(unittest.TestCase):
 class DecimalTest(unittest.TestCase):
     def setUp(self):
         set_locale(locale.LC_NUMERIC, 'C')
-        self.conv = converter.get_converter(Decimal)
+        self.conv = converter.get_converter(decimal.Decimal)
 
     def tearDown(self):
         set_locale(locale.LC_NUMERIC, 'C')
 
     def testFromString(self):
-        self.assertEqual(self.conv.from_string('-2.5'), Decimal('-2.5'))
-        self.assertEqual(self.conv.from_string('10.33'), Decimal('10.33'))
+        self.assertEqual(self.conv.from_string('-2.5'), decimal.Decimal('-2.5'))
+        self.assertEqual(self.conv.from_string('10.33'), decimal.Decimal('10.33'))
         self.assertRaises(ValidationError, self.conv.from_string, 'foo')
         self.assertRaises(ValidationError, self.conv.from_string, '1.2.3')
         self.assertEqual(self.conv.from_string(''), ValueUnset)
 
+    def testFromStringUS(self):
+        if not set_locale(locale.LC_NUMERIC, 'en_US'):
+            return
+        self.assertEqual(
+            self.conv.from_string('10,000,000.0'), decimal.Decimal('10000000'))
+        self.assertEqual(
+            self.conv.from_string('10,000,000.0'), decimal.Decimal('10000000.0'))
+        # pt_BR style decimals should raise ValidationError
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, '10.000.000,0')
+
+    def testFromStringBR(self):
+        if not set_locale(locale.LC_NUMERIC, 'pt_BR'):
+            return
+        self.assertEqual(
+            self.conv.from_string('10.000.000,0'), decimal.Decimal('10000000'))
+        self.assertEqual(
+            self.conv.from_string('10.000.000,0'), decimal.Decimal('10000000.0'))
+        # en_US style decimals should raise ValidationError
+        self.assertRaises(ValidationError,
+                          self.conv.from_string, '10,000,000.0')
+
     def testAsString(self):
-        self.assertEqual(self.conv.as_string(Decimal('0.0')), '0.0')
-        self.assertEqual(self.conv.as_string(Decimal('0.5')), '0.5')
-        self.assertEqual(self.conv.as_string(Decimal('-0.5')), '-0.5')
-        self.assertEqual(self.conv.as_string(Decimal('0.123456789')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('0.0')), '0.0')
+        self.assertEqual(self.conv.as_string(decimal.Decimal('0.5')), '0.5')
+        self.assertEqual(self.conv.as_string(decimal.Decimal('-0.5')), '-0.5')
+        self.assertEqual(self.conv.as_string(decimal.Decimal('0.123456789')),
                          '0.123456789')
-        self.assertEqual(self.conv.as_string(Decimal('-0.123456789')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('-0.123456789')),
                          '-0.123456789')
-        self.assertEqual(self.conv.as_string(Decimal('10000000')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('10000000')),
                          '10000000.0')
-        self.assertEqual(self.conv.as_string(Decimal('10000000.0')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('10000000.0')),
                          '10000000.0')
 
     def testAsStringUS(self):
         if not set_locale(locale.LC_NUMERIC, 'en_US'):
             return
-        self.assertEqual(self.conv.as_string(Decimal('10000000')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('10000000')),
                          '10,000,000.0')
-        self.assertEqual(self.conv.as_string(Decimal('10000000.0')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('10000000.0')),
                          '10,000,000.0')
 
+    def testAsStringBR(self):
+        if not set_locale(locale.LC_NUMERIC, 'pt_BR'):
+            return
+        self.assertEqual(
+            self.conv.as_string(decimal.Decimal('10000000')), '10.000.000,0')
+        self.assertEqual(
+            self.conv.as_string(decimal.Decimal('10000000.0')), '10.000.000,0')
+        self.assertEqual(
+            self.conv.as_string(decimal.Decimal('0.0')), '0,0')
+        self.assertEqual(
+            self.conv.as_string(decimal.Decimal('0.5')), '0,5')
+        self.assertEqual(
+            self.conv.as_string(decimal.Decimal('-0.5')), '-0,5')
+        self.assertEqual(
+            self.conv.as_string(decimal.Decimal('0.123456789')), '0,123456789')
+
     def testAsStringSE(self):
         if not set_locale(locale.LC_NUMERIC, 'sv_SE'):
             return
-        self.assertEqual(self.conv.as_string(Decimal('0.0')), '0,0')
-        self.assertEqual(self.conv.as_string(Decimal('0.5')), '0,5')
-        self.assertEqual(self.conv.as_string(Decimal('-0.5')), '-0,5')
-        self.assertEqual(self.conv.as_string(Decimal('0.123456789')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('0.0')), '0,0')
+        self.assertEqual(self.conv.as_string(decimal.Decimal('0.5')), '0,5')
+        self.assertEqual(self.conv.as_string(decimal.Decimal('-0.5')), '-0,5')
+        self.assertEqual(self.conv.as_string(decimal.Decimal('0.123456789')),
                          '0,123456789')
-        self.assertEqual(self.conv.as_string(Decimal('-0.123456789')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('-0.123456789')),
                          '-0,123456789')
-        self.assertEqual(self.conv.as_string(Decimal('10000000')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('10000000')),
                          '10 000 000,0')
-        self.assertEqual(self.conv.as_string(Decimal('10000000.0')),
+        self.assertEqual(self.conv.as_string(decimal.Decimal('10000000.0')),
                          '10 000 000,0')
 
 
